==> 0.0.2.tar.gz: lib/flython.dart <==
library flython;

import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'package:mutex/mutex.dart';
import 'package:uuid/uuid.dart';

/// Flython
class Flython {
  static const _mainAppContents = '''
import argparse
import json
import sys

CMD_SYS_VERSION = 0


def run(command):
    if command["cmd"] == CMD_SYS_VERSION:
        return {
            "sys.version": sys.version,
        }

    else:
        return {"error": "Unknown command."}


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--uuid")
    args = parser.parse_args()
    stream_start = f"`S`T`R`E`A`M`{args.uuid}`S`T`A`R`T`"
    stream_end = f"`S`T`R`E`A`M`{args.uuid}`E`N`D`"
    while True:
        cmd = input()
        cmd = json.loads(cmd)
        try:
            result = run(cmd)
        except Exception as e:
            result = {"exception": e.__str__()}
        result = json.dumps(result)
        print(stream_start + result + stream_end)

''';

  final _instanceUuid = const Uuid().v4();
  var _resultCompleter = Completer();
  late String _result;
  late Process _process;
  final _runCmdMutex = Mutex();

  static const cmdSysVersion = 0;

  String _streamStart() => "`S`T`R`E`A`M`$_instanceUuid`S`T`A`R`T`";

  String _streamEnd() => "`S`T`R`E`A`M`$_instanceUuid`E`N`D`";

  bool debugMode = false;
  final logFile = File(
    "./" + DateTime.now().toIso8601String().replaceAll(":", "-") + ".log",
  );

  void log(String text) {
    if (debugMode) {
      print(text);
      logFile.writeAsStringSync(
        DateTime.now().toIso8601String() + " => " + text + "\n\n",
        mode: FileMode.append,
      );
    }
  }

  Future<bool> initialize(
    String pythonCommand,
    String mainApp,
    bool debugMode,
  ) async {
    if (!File(mainApp).existsSync()) {
      File(mainApp).writeAsStringSync(_mainAppContents);
    }
    this.debugMode = debugMode;
    if (debugMode) logFile.openWrite();
    return await _runCmdMutex.protect<bool>(() async {
      return await _initializeUnprotected(pythonCommand, mainApp);
    });
  }

  Future<bool> _initializeUnprotected(
    String pythonCommand,
    String mainApp,
  ) async {
    _process = await Process.start(
      pythonCommand,
      [mainApp, "--uuid", _instanceUuid],
    );
    _process.stdout.transform(utf8.decoder).forEach((element) {
      log(element);
      _result += element;
      if (_result.contains(_streamEnd()) && !_resultCompleter.isCompleted) {
        _resultCompleter.complete(_result
            .split(_streamStart())[1]
            .replaceAll(_streamEnd(), "")
            .trim());
      }
    });
    _process.stderr.transform(utf8.decoder).forEach((element) {
      log(element);
    });
    return true;
  }

  Future<dynamic> _runCommand(dynamic command) async {
    return await _runCmdMutex.protect<dynamic>(() async {
      return await _runCommandUnprotected(command);
    });
  }

  Future<dynamic> _runCommandUnprotected(dynamic command) async {
    final jsCommand = jsonEncode(command);
    _resultCompleter = Completer();
    _result = "";
    _process.stdin.writeln(jsCommand);
    log(jsCommand);
    final jsResult = await _resultCompleter.future;
    return jsonDecode(jsResult);
  }

  Future<dynamic> sysVersion() async {
    var command = {"cmd": cmdSysVersion};
    return await _runCommand(command);
  }
}

==> 0.0.4.tar.gz: lib/flython.dart <==
library flython;

import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'package:mutex/mutex.dart';
import 'package:uuid/uuid.dart';

/// Flython
class Flython {
  static const _mainAppContents = '''
import argparse
import json
import sys

CMD_SYS_VERSION = 0


def run(command):
    if command["cmd"] == CMD_SYS_VERSION:
        return {
            "sys.version": sys.version,
        }

    else:
        return {"error": "Unknown command."}


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--uuid")
    args = parser.parse_args()
    stream_start = f"`S`T`R`E`A`M`{args.uuid}`S`T`A`R`T`"
    stream_end = f"`S`T`R`E`A`M`{args.uuid}`E`N`D`"
    while True:
        cmd = input()
        cmd = json.loads(cmd)
        try:
            result = run(cmd)
        except Exception as e:
            result = {"exception": e.__str__()}
        result = json.dumps(result)
        print(stream_start + result + stream_end)

''';

  final _instanceUuid = const Uuid().v4();
  var _resultCompleter = Completer();
  late String _result;
  late Process _process;
  final _runCmdMutex = Mutex();

  static const cmdSysVersion = 0;

  String _streamStart() => "`S`T`R`E`A`M`$_instanceUuid`S`T`A`R`T`";

  String _streamEnd() => "`S`T`R`E`A`M`$_instanceUuid`E`N`D`";

  bool debugMode = false;
  final logFile = File(
    "./" + DateTime.now().toIso8601String().replaceAll(":", "-") + ".log",
  );

  void log(String text) {
    if (debugMode) {
      print(text);
      logFile.writeAsStringSync(
        DateTime.now().toIso8601String() + " => " + text + "\n\n",
        mode: FileMode.append,
      );
    }
  }

  Future<bool> initialize(
    String pythonCommand,
    String mainApp,
    bool debugMode,
  ) async {
    if (!File(mainApp).existsSync()) {
      File(mainApp).writeAsStringSync(_mainAppContents);
    }
    this.debugMode = debugMode;
    if (debugMode) logFile.openWrite();
    return await _runCmdMutex.protect<bool>(() async {
      return await _initializeUnprotected(pythonCommand, mainApp);
    });
  }

  Future<bool> _initializeUnprotected(
    String pythonCommand,
    String mainApp,
  ) async {
    _process = await Process.start(
      pythonCommand,
      [mainApp, "--uuid", _instanceUuid],
    );
    _process.stdout.transform(utf8.decoder).forEach((element) {
      log(element);
      _result += element;
      if (_result.contains(_streamEnd()) && !_resultCompleter.isCompleted) {
        _resultCompleter.complete(_result
            .split(_streamStart())[1]
            .replaceAll(_streamEnd(), "")
            .trim());
      }
    });
    _process.stderr.transform(utf8.decoder).forEach((element) {
      log(element);
    });
    return true;
  }

  Future<dynamic> _runCommandUnprotected(dynamic command) async {
    final jsCommand = jsonEncode(command);
    _resultCompleter = Completer();
    _result = "";
    _process.stdin.writeln(jsCommand);
    log(jsCommand);
    final jsResult = await _resultCompleter.future;
    return jsonDecode(jsResult);
  }

  Future<dynamic> runCommand(dynamic command) async {
    return await _runCmdMutex.protect<dynamic>(() async {
      return await _runCommandUnprotected(command);
    });
  }

  Future<dynamic> sysVersion() async {
    var command = {"cmd": cmdSysVersion};
    return await runCommand(command);
  }
}
